@@ -1,6 +1,6 @@
 /*
  * rsyncrypto - an rsync friendly encryption
- * Copyright (C) 2005 Shachar Shemesh for Lingnu Open Source Consulting ltd.
+ * Copyright (C) 2005,2006 Shachar Shemesh for Lingnu Open Source Consulting ltd.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -107,13 +107,19 @@ void filelist_encrypt( const char *src, const char *dst_dir, const char *key_dir
             switch( filestat.st_mode&S_IFMT ) {
             case S_IFREG:
                 {
-                    if( VERBOSE(1) )
-                        std::cerr<<opname<<" file: "<<srcname<<std::endl;
-
                     std::string dstfile=dstnameop( dst_dir, srcname.c_str(), filestat.st_mode );
                     std::string keyfile=keynameop( key_dir, srcname.c_str(), filestat.st_mode );
 
-                    op( src.c_str(), dstfile.c_str(), keyfile.c_str(), rsa_key );
+		    struct stat dststat;
+		    if( !EXISTS(changed) || lstat( dstfile.c_str(), &dststat )!=0 ||
+			    dststat.st_mtime!=filestat.st_mtime ) {
+			if( VERBOSE(1) )
+			    std::cerr<<opname<<" file: "<<srcname<<std::endl;
+
+			op( src.c_str(), dstfile.c_str(), keyfile.c_str(), rsa_key );
+		    } else if( VERBOSE(1) ) {
+                        std::cerr<<opname<<": skipped unchanged file: "<<srcname<<std::endl;
+		    }
                 }
                 break;
             case S_IFDIR:
@@ -306,7 +312,7 @@ void file_encrypt( const char *source_file, const char *dst_file, const char *ke
 #endif
     bool archive=!EXISTS(noarch);
 
-    autofd infd;
+    read_bufferfd infd;
     if( strcmp(source_file, "-")!=0 )
         infd=autofd(source_file, open_flags);
     else {
@@ -316,7 +322,7 @@ void file_encrypt( const char *source_file, const char *dst_file, const char *ke
     }
 
     autofd::mkpath( std::string(dst_file, autofd::dirpart(dst_file)).c_str(), 0777 );
-    autofd outfd(dst_file, O_CREAT|O_TRUNC|O_RDWR, 0666);
+    write_bufferfd outfd(autofd(dst_file, O_CREAT|O_TRUNC|O_RDWR, 0666));
     encrypt_file( head.get(), rsa_key, infd, outfd );
     if( !headfd.valid() ) {
         write_header( key_file, head.get() );
@@ -352,11 +358,11 @@ void file_decrypt( const char *src_file, const char *dst_file, const char *key_f
         headfd.clear();
     }
 
-    autofd infd(src_file, O_RDONLY);
+    read_bufferfd infd(autofd(src_file, O_RDONLY));
     status=infd.fstat();
 
     autofd::mkpath( std::string(dst_file, autofd::dirpart(dst_file)).c_str(), 0777);
-    autofd outfd(dst_file, O_CREAT|O_TRUNC|O_WRONLY, 0666);
+    write_bufferfd outfd(autofd(dst_file, O_CREAT|O_TRUNC|O_WRONLY, 0666));
     head=std::auto_ptr<key>(decrypt_file( head.get(), rsa_key, infd, outfd ));
     if( !headeread ) {
         write_header( key_file, head.get());
